#ifndef __THREAD_H_
#define __THREAD_H_

void *print_stdout(void *);
void *print_stderr(void *);
int run_command(char *command, char *window_name, int dsize, int wait, int is_process, char *cmd);
int copy_image(char *window_name);

#endif
